==> cxf-services-xkms-common-3.0.16-sources.jar: org/apache/cxf/xkms/model/xkms/RevokeRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RevokeRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RevokeRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeKeyBinding"/&gt;
 *         &lt;choice&gt;
 *           &lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&gt;
 *           &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevocationCode"/&gt;
 *         &lt;/choice&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RevokeRequestType", propOrder = {
    "revokeKeyBinding",
    "authentication",
    "revocationCode"
})
public class RevokeRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "RevokeKeyBinding", required = true)
    protected KeyBindingType revokeKeyBinding;
    @XmlElement(name = "Authentication")
    protected AuthenticationType authentication;
    @XmlElement(name = "RevocationCode")
    protected byte[] revocationCode;

    /**
     * Gets the value of the revokeKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingType }
     *     
     */
    public KeyBindingType getRevokeKeyBinding() {
        return revokeKeyBinding;
    }

    /**
     * Sets the value of the revokeKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingType }
     *     
     */
    public void setRevokeKeyBinding(KeyBindingType value) {
        this.revokeKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

    /**
     * Gets the value of the revocationCode property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getRevocationCode() {
        return revocationCode;
    }

    /**
     * Sets the value of the revocationCode property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setRevocationCode(byte[] value) {
        this.revocationCode = value;
    }

}

==> cxf-services-xkms-common-3.3.12-sources.jar: org/apache/cxf/xkms/model/xkms/RevokeRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for RevokeRequestType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="RevokeRequestType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeKeyBinding"/&amp;gt;
 *         &amp;lt;choice&amp;gt;
 *           &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&amp;gt;
 *           &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}RevocationCode"/&amp;gt;
 *         &amp;lt;/choice&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/extension&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RevokeRequestType", propOrder = {
    "revokeKeyBinding",
    "authentication",
    "revocationCode"
})
public class RevokeRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "RevokeKeyBinding", required = true)
    protected KeyBindingType revokeKeyBinding = new KeyBindingType();
    @XmlElement(name = "Authentication")
    protected AuthenticationType authentication = new AuthenticationType();
    @XmlElement(name = "RevocationCode")
    protected byte[] revocationCode;

    /**
     * Gets the value of the revokeKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingType }
     *     
     */
    public KeyBindingType getRevokeKeyBinding() {
        return revokeKeyBinding;
    }

    /**
     * Sets the value of the revokeKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingType }
     *     
     */
    public void setRevokeKeyBinding(KeyBindingType value) {
        this.revokeKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

    /**
     * Gets the value of the revocationCode property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getRevocationCode() {
        return revocationCode;
    }

    /**
     * Sets the value of the revocationCode property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setRevocationCode(byte[] value) {
        this.revocationCode = value;
    }

}
